@@ -1,9 +1,9 @@
 ## File Name: tam_mml_se_quick_likelihood.R
-## File Version: 0.06
+## File Version: 0.07
 
 
 tam_mml_se_quick_likelihood <- function( nitems, A, AXsi, B, xsi, theta, nnodes, maxK,
-        gwt, resp, resp.ind.list, snodes, thetawidth )
+        gwt, resp, resp.ind.list, snodes, thetawidth, thetasamp.density=NULL )
 {
     # calculate probabilities
     res0 <- tam_mml_calc_prob( iIndex=1:nitems, A=A, AXsi=AXsi, B=B,
@@ -12,7 +12,7 @@ tam_mml_se_quick_likelihood <- function( nitems, A, AXsi, B, xsi, theta, nnodes,
     # calculate likelihood
     like0 <- tam_calc_posterior(rprobs=rprobs, gwt=gwt, resp=resp,
                                 nitems=nitems, resp.ind.list=resp.ind.list,
-                                normalization=FALSE, thetasamp.density=NULL,
+                                normalization=FALSE, thetasamp.density=thetasamp.density,
                                 snodes=snodes )$hwt
     # calculate individual log likelihood
     res <- tam_mml_se_quick_compute_log_likelihood( like0=like0,
